/*
	Copyright (c) 2004 Jonatan Kronqvist

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the "Software"),
	to deal in the Software without restriction, including without limitation
	the rights to use, copy, modify, merge, publish, distribute, sublicense,
	and/or sell copies of the Software, and to permit persons to whom the
	Software is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
	FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
	IN THE SOFTWARE.
*/



#ifndef __FOOBAR_CONTROL_H__
#define __FOOBAR_CONTROL_H__


#include "../SDK/foobar2000.h"
#include "../helpers/helpers.h"

#include <vector>
#include "control.h"


extern void g_debug(string8 str);



class foobar_control : public control
{
public:
	void fade_stop();					// fade and stop
	void ffwd(long secs);				// fast forward
	void rwnd(long secs);				// rewind
	void next(bool random);				// advance in playlist
	void prev();						// previous in playlist
	void pause();						// pause
	void stop();						// stop immediately
	void play(string8 fname);			// play file
	void play_current();				// play current file in playlist
	long get_playlist_len();			// returns the length of the playlist
	std::vector<string8> *get_playlist();// returns a vector with the playlist
	void add_to_playlist(string8 fname);// add a file to the playlist
	void select_at(int idx);			// select the song at idx in playlist
	void clear_playlist();				// clear the playlist
	void set_repeat(bool repeat);		// set repeat
	void set_shuffle(bool shuffle);		// set shuffle
	void seek(long pos);				// seek to position
	void set_stop_at_eof_track(bool stop);// guess
	void set_volume(unsigned char vol);	// set volume
	unsigned char get_volume();			// return volume
	long get_bitrate();					// return bitrate of current song
	long get_samplerate();				// return samplerate of current song
	long get_channels();				// return number of channels of current song
	const char* get_file_path();		// return the path of the current song
	long get_playback_time();			// return played seconds
	long get_playlength();				// return playlength
	bool get_shuffle();					// return shuffle state
	bool get_repeat();					// return repeat state
	void get_title(string8 &str);		// return the title of the current song
	bool is_paused();					// return if paused
	bool is_playing();					// return if playing
	long get_cur_idx();					// return current playlist index

	void set_playlist_fmt(string8 playlist_fmt);
private:
	metadb	*m_mdb;
	bool	m_shuffle;
	string8	m_playlist_fmt;
};


#endif /*__FOOBAR_CONTROL_H__*/